@@ -88,18 +88,14 @@ static char messageBuffer[ERROR_MESSAGE_BUFFER_SIZE];
 static char messageBufferTemp[ERROR_MESSAGE_BUFFER_SIZE];
 static char stackTraceBuffer[ERROR_MESSAGE_BUFFER_SIZE];
 
-/***********************************************************************************************************************************
-Error type code
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 errorTypeCode(const ErrorType *errorType)
 {
     return errorType->code;
 }
 
-/***********************************************************************************************************************************
-Get error type using a code
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const ErrorType *
 errorTypeFromCode(int code)
 {
@@ -122,35 +118,27 @@ errorTypeFromCode(int code)
     return result;
 }
 
-/***********************************************************************************************************************************
-Error type name
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorTypeName(const ErrorType *errorType)
 {
     return errorType->name;
 }
 
-/***********************************************************************************************************************************
-Error type parent
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const ErrorType *
 errorTypeParent(const ErrorType *errorType)
 {
     return errorType->parentType;
 }
 
-/***********************************************************************************************************************************
-Get the depth of the current try statement (0 if none)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int errorTryDepth(void)
 {
     return (unsigned int)errorContext.tryTotal;
 }
 
-/***********************************************************************************************************************************
-Does the child error type extend the parent error type?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorTypeExtends(const ErrorType *child, const ErrorType *parent)
 {
@@ -170,81 +158,63 @@ errorTypeExtends(const ErrorType *child, const ErrorType *parent)
     return false;
 }
 
-/***********************************************************************************************************************************
-Error type
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const ErrorType *
 errorType(void)
 {
     return errorContext.error.errorType;
 }
 
-/***********************************************************************************************************************************
-Error code (pulled from error type)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 errorCode(void)
 {
     return errorTypeCode(errorType());
 }
 
-/***********************************************************************************************************************************
-Error filename
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorFileName(void)
 {
     return errorContext.error.fileName;
 }
 
-/***********************************************************************************************************************************
-Error function name
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorFunctionName(void)
 {
     return errorContext.error.functionName;
 }
 
-/***********************************************************************************************************************************
-Error file line number
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 errorFileLine(void)
 {
     return errorContext.error.fileLine;
 }
 
-/***********************************************************************************************************************************
-Error message
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorMessage(void)
 {
     return errorContext.error.message;
 }
 
-/***********************************************************************************************************************************
-Error name (pulled from error type)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorName(void)
 {
     return errorTypeName(errorType());
 }
 
-/***********************************************************************************************************************************
-Error stack trace
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 errorStackTrace(void)
 {
     return errorContext.error.stackTrace;
 }
 
-/***********************************************************************************************************************************
-Is this error an instance of the error type?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInstanceOf(const ErrorType *errorTypeTest)
 {
@@ -260,18 +230,14 @@ errorInternalState(void)
     return errorContext.tryList[errorContext.tryTotal].state;
 }
 
-/***********************************************************************************************************************************
-True when in try state
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalStateTry(void)
 {
     return errorInternalState() == errorStateTry;
 }
 
-/***********************************************************************************************************************************
-True when in catch state and the expected error matches
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalStateCatch(const ErrorType *errorTypeCatch)
 {
@@ -281,27 +247,21 @@ errorInternalStateCatch(const ErrorType *errorTypeCatch)
     return false;
 }
 
-/***********************************************************************************************************************************
-True when in final state
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalStateFinal(void)
 {
     return errorInternalState() == errorStateFinal;
 }
 
-/***********************************************************************************************************************************
-Return jump buffer for current try
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 jmp_buf *
 errorInternalJump(void)
 {
     return &errorContext.jumpList[errorContext.tryTotal - 1];
 }
 
-/***********************************************************************************************************************************
-Begin the try block
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalTry(const char *fileName, const char *functionName, int fileLine)
 {
@@ -320,9 +280,7 @@ errorInternalTry(const char *fileName, const char *functionName, int fileLine)
     return true;
 }
 
-/***********************************************************************************************************************************
-Propagate the error up so it can be caught
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 errorInternalPropagate(void)
 {
@@ -341,9 +299,7 @@ errorInternalPropagate(void)
     exit(UnhandledError.code);
 }
 
-/***********************************************************************************************************************************
-Process the error through each try and state
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 errorInternalProcess(bool catch)
 {
@@ -385,9 +341,7 @@ errorInternalProcess(bool catch)
     return false;
 }
 
-/***********************************************************************************************************************************
-Throw an error
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 errorInternalThrow(const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
 {
@@ -429,24 +383,11 @@ errorInternalThrowFmt(
     errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
 }
 
-/***********************************************************************************************************************************
-Throw a system error
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 errorInternalThrowSys(
-#ifdef DEBUG_COVERAGE
-    bool error,
-#else
-    int errNo,
-#endif
-    const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
+    int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
 {
-#ifdef DEBUG_COVERAGE
-    if (error)
-    {
-        int errNo = errno;
-#endif
-
     // Format message with system message appended
     if (errNo == 0)
     {
@@ -457,27 +398,23 @@ errorInternalThrowSys(
         snprintf(messageBufferTemp, ERROR_MESSAGE_BUFFER_SIZE - 1, "%s: [%d] %s", message, errNo, strerror(errNo));
 
     errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
+}
 
 #ifdef DEBUG_COVERAGE
-    }
-#endif
+void
+errorInternalThrowOnSys(
+    bool error, int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine,
+    const char *message)
+{
+    if (error)
+        errorInternalThrowSys(errNo, errorType, fileName, functionName, fileLine, message);
 }
+#endif
 
 void
 errorInternalThrowSysFmt(
-#ifdef DEBUG_COVERAGE
-    bool error,
-#else
-    int errNo,
-#endif
-    const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
+    int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
 {
-#ifdef DEBUG_COVERAGE
-    if (error)
-    {
-        int errNo = errno;
-#endif
-
     // Format message
     va_list argument;
     va_start(argument, format);
@@ -489,8 +426,30 @@ errorInternalThrowSysFmt(
         snprintf(messageBufferTemp + messageSize, ERROR_MESSAGE_BUFFER_SIZE - 1 - messageSize, ": [%d] %s", errNo, strerror(errNo));
 
     errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
+}
 
 #ifdef DEBUG_COVERAGE
+void
+errorInternalThrowOnSysFmt(
+    bool error, int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine,
+    const char *format, ...)
+{
+    if (error)
+    {
+        // Format message
+        va_list argument;
+        va_start(argument, format);
+        size_t messageSize = (size_t)vsnprintf(messageBufferTemp, ERROR_MESSAGE_BUFFER_SIZE - 1, format, argument);
+        va_end(argument);
+
+        // Append the system message
+        if (errNo != 0)
+        {
+            snprintf(
+                messageBufferTemp + messageSize, ERROR_MESSAGE_BUFFER_SIZE - 1 - messageSize, ": [%d] %s", errNo, strerror(errNo));
+        }
+
+        errorInternalThrow(errorType, fileName, functionName, fileLine, messageBufferTemp);
     }
-#endif
 }
+#endif
