@@ -22,10 +22,9 @@ Max call stack depth
 #define STACK_TRACE_MAX                                             128
 
 /***********************************************************************************************************************************
-Track stack trace
+Local variables
 ***********************************************************************************************************************************/
-static int stackSize = 0;
-
+// Stack trace function data
 typedef struct StackTraceData
 {
     const char *fileName;
@@ -34,31 +33,32 @@ typedef struct StackTraceData
     LogLevel functionLogLevel;
     unsigned int tryDepth;
 
-    char *param;
-    size_t paramSize;
     bool paramOverflow;
     bool paramLog;
+    char *param;
+    size_t paramSize;
 } StackTraceData;
 
-static StackTraceData stackTrace[STACK_TRACE_MAX];
+static struct StackTraceLocal
+{
+    int stackSize;                                                  // Stack size
+    StackTraceData stack[STACK_TRACE_MAX];                          // Stack data
+    char functionParamBuffer[32 * 1024];                            // Buffer to hold function parameters
+} stackTraceLocal;
 
-/***********************************************************************************************************************************
-Buffer to hold function parameters
-***********************************************************************************************************************************/
-static char functionParamBuffer[32 * 1024];
-
-struct backtrace_state *backTraceState = NULL;
-
-/***********************************************************************************************************************************
-Backtrace init and callbacks
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 #ifdef WITH_BACKTRACE
 
+static struct StackTraceBackLocal
+{
+    struct backtrace_state *backTraceState;                         // Backtrace state struct
+} stackTraceBackLocal
+
 void
 stackTraceInit(const char *exe)
 {
-    if (backTraceState == NULL)
-        backTraceState = backtrace_create_state(exe, false, NULL, NULL);
+    if (stackTraceBackLocal.backTraceState == NULL)
+        stackTraceBackLocal.backTraceState = backtrace_create_state(exe, false, NULL, NULL);
 }
 
 static int
@@ -69,8 +69,8 @@ backTraceCallback(void *data, uintptr_t pc, const char *filename, int lineno, co
     (void)(filename);
     (void)(function);
 
-    if (stackSize > 0)
-        stackTrace[stackSize - 1].fileLine = (unsigned int)lineno;
+    if (stackTraceLocal.stackSize > 0)
+        stackTraceLocal.stack[stackTraceLocal.stackSize - 1].fileLine = (unsigned int)lineno;
 
     return 1;
 }
@@ -85,54 +85,55 @@ backTraceCallbackError(void *data, const char *msg, int errnum)
 
 #endif
 
-/***********************************************************************************************************************************
-Flag to enable/disable test function logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 #ifndef NDEBUG
 
-bool stackTraceTestFlag = true;
+static struct StackTraceTestLocal
+{
+    bool testFlag;                                        // Don't log in parameter logging functions to avoid recursion
+} stackTraceTestLocal = {.testFlag = true};
 
 void
 stackTraceTestStart(void)
 {
-    stackTraceTestFlag = true;
+    stackTraceTestLocal.testFlag = true;
 }
 
 void
 stackTraceTestStop(void)
 {
-    stackTraceTestFlag = false;
+    stackTraceTestLocal.testFlag = false;
 }
 
 bool
 stackTraceTest(void)
 {
-    return stackTraceTestFlag;
+    return stackTraceTestLocal.testFlag;
 }
 
 void
 stackTraceTestFileLineSet(unsigned int fileLine)
 {
-    stackTrace[stackSize - 1].fileLine = fileLine;
+    ASSERT(stackTraceLocal.stackSize > 0);
+
+    stackTraceLocal.stack[stackTraceLocal.stackSize - 1].fileLine = fileLine;
 }
 
 #endif
 
-/***********************************************************************************************************************************
-Push a new function onto the trace stack
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 LogLevel
 stackTracePush(const char *fileName, const char *functionName, LogLevel functionLogLevel)
 {
-    ASSERT(stackSize < STACK_TRACE_MAX - 1);
+    ASSERT(stackTraceLocal.stackSize < STACK_TRACE_MAX - 1);
 
     // Get line number from backtrace if available
 #ifdef WITH_BACKTRACE
-    backtrace_full(backTraceState, 2, backTraceCallback, backTraceCallbackError, NULL);
+    backtrace_full(stackTraceBackLocal.backTraceState, 2, backTraceCallback, backTraceCallbackError, NULL);
 #endif
 
     // Set function info
-    StackTraceData *data = &stackTrace[stackSize];
+    StackTraceData *data = &stackTraceLocal.stack[stackTraceLocal.stackSize];
 
     *data = (StackTraceData)
     {
@@ -142,14 +143,14 @@ stackTracePush(const char *fileName, const char *functionName, LogLevel function
     };
 
     // Set param pointer
-    if (stackSize == 0)
+    if (stackTraceLocal.stackSize == 0)
     {
-        data->param = functionParamBuffer;
+        data->param = stackTraceLocal.functionParamBuffer;
         data->functionLogLevel = functionLogLevel;
     }
     else
     {
-        StackTraceData *dataPrior = &stackTrace[stackSize - 1];
+        StackTraceData *dataPrior = &stackTraceLocal.stack[stackTraceLocal.stackSize - 1];
 
         data->param = dataPrior->param + dataPrior->paramSize + 1;
 
@@ -160,21 +161,19 @@ stackTracePush(const char *fileName, const char *functionName, LogLevel function
             data->functionLogLevel = functionLogLevel;
     }
 
-    stackSize++;
+    stackTraceLocal.stackSize++;
 
     return data->functionLogLevel;
 }
 
-/***********************************************************************************************************************************
-Get parameters for the top function on the stack
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 static const char *
 stackTraceParamIdx(int stackIdx)
 {
-    ASSERT(stackSize > 0);
-    ASSERT(stackIdx < stackSize);
+    ASSERT(stackTraceLocal.stackSize > 0);
+    ASSERT(stackIdx < stackTraceLocal.stackSize);
 
-    StackTraceData *data = &stackTrace[stackIdx];
+    StackTraceData *data = &stackTraceLocal.stack[stackIdx];
 
     if (data->paramLog)
     {
@@ -195,23 +194,21 @@ stackTraceParamIdx(int stackIdx)
 const char *
 stackTraceParam()
 {
-    return stackTraceParamIdx(stackSize - 1);
+    return stackTraceParamIdx(stackTraceLocal.stackSize - 1);
 }
 
-/***********************************************************************************************************************************
-Get the next location where a parameter can be added in the param buffer
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 char *
 stackTraceParamBuffer(const char *paramName)
 {
-    ASSERT(stackSize > 0);
+    ASSERT(stackTraceLocal.stackSize > 0);
 
-    StackTraceData *data = &stackTrace[stackSize - 1];
+    StackTraceData *data = &stackTraceLocal.stack[stackTraceLocal.stackSize - 1];
     size_t paramNameSize = strlen(paramName);
 
     // Make sure that adding this parameter will not overflow the buffer
-    if ((size_t)(data->param - functionParamBuffer) + data->paramSize + paramNameSize + 4 >
-        sizeof(functionParamBuffer) - (STACK_TRACE_PARAM_MAX * 2))
+    if ((size_t)(data->param - stackTraceLocal.functionParamBuffer) + data->paramSize + paramNameSize + 4 >
+        sizeof(stackTraceLocal.functionParamBuffer) - (STACK_TRACE_PARAM_MAX * 2))
     {
         // Set overflow to true
         data->paramOverflow = true;
@@ -219,7 +216,7 @@ stackTraceParamBuffer(const char *paramName)
         // There's no way to stop the parameter from being formatted so we reserve a space at the end where the format can safely
         // take place and not disturb the rest of the buffer.  Hopefully overflows just won't happen but we need to be prepared in
         // case of runaway recursion or some other issue that fills the buffer because we don't want a segfault.
-        return functionParamBuffer + sizeof(functionParamBuffer) - STACK_TRACE_PARAM_MAX;
+        return stackTraceLocal.functionParamBuffer + sizeof(stackTraceLocal.functionParamBuffer) - STACK_TRACE_PARAM_MAX;
     }
 
     // Add a comma if a parameter is already in the list
@@ -240,40 +237,34 @@ stackTraceParamBuffer(const char *paramName)
     return data->param + data->paramSize;
 }
 
-/***********************************************************************************************************************************
-Add a parameter to the function on the top of the stack
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 stackTraceParamAdd(size_t bufferSize)
 {
-    ASSERT(stackSize > 0);
+    ASSERT(stackTraceLocal.stackSize > 0);
 
-    StackTraceData *data = &stackTrace[stackSize - 1];
+    StackTraceData *data = &stackTraceLocal.stack[stackTraceLocal.stackSize - 1];
 
     if (!data->paramOverflow)
         data->paramSize += bufferSize;
 }
 
-/***********************************************************************************************************************************
-Mark that parameters are being logged -- it none appear then the function is void
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 stackTraceParamLog(void)
 {
-    ASSERT(stackSize > 0);
+    ASSERT(stackTraceLocal.stackSize > 0);
 
-    stackTrace[stackSize - 1].paramLog = true;
+    stackTraceLocal.stack[stackTraceLocal.stackSize - 1].paramLog = true;
 }
 
-/***********************************************************************************************************************************
-Pop a function from the stack trace
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 #ifdef NDEBUG
 
 void
 stackTracePop(void)
 {
-    stackSize--;
+    stackTraceLocal.stackSize--;
 }
 
 #else
@@ -281,13 +272,13 @@ stackTracePop(void)
 void
 stackTracePop(const char *fileName, const char *functionName, bool test)
 {
-    ASSERT(stackSize > 0);
+    ASSERT(stackTraceLocal.stackSize > 0);
 
     if (!test || stackTraceTest())
     {
-        stackSize--;
+        stackTraceLocal.stackSize--;
 
-        StackTraceData *data = &stackTrace[stackSize];
+        StackTraceData *data = &stackTraceLocal.stack[stackTraceLocal.stackSize];
 
         if (strcmp(data->fileName, fileName) != 0 || strcmp(data->functionName, functionName) != 0)
             THROW_FMT(AssertError, "popping %s:%s but expected %s:%s", fileName, functionName, data->fileName, data->functionName);
@@ -311,21 +302,19 @@ stackTraceFmt(char *buffer, size_t bufferSize, size_t bufferUsed, const char *fo
     return (size_t)result;
 }
 
-/***********************************************************************************************************************************
-Generate the stack trace
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 stackTraceToZ(char *buffer, size_t bufferSize, const char *fileName, const char *functionName, unsigned int fileLine)
 {
     size_t result = 0;
     const char *param = "test build required for parameters";
-    int stackIdx = stackSize - 1;
+    int stackIdx = stackTraceLocal.stackSize - 1;
 
     // If the current function passed in is the same as the top function on the stack then use the parameters for that function
-    if (stackSize > 0 && strcmp(fileName, stackTrace[stackIdx].fileName) == 0 &&
-        strcmp(functionName, stackTrace[stackIdx].functionName) == 0)
+    if (stackTraceLocal.stackSize > 0 && strcmp(fileName, stackTraceLocal.stack[stackIdx].fileName) == 0 &&
+        strcmp(functionName, stackTraceLocal.stack[stackIdx].functionName) == 0)
     {
-        param = stackTraceParamIdx(stackSize - 1);
+        param = stackTraceParamIdx(stackTraceLocal.stackSize - 1);
         stackIdx--;
     }
 
@@ -337,13 +326,13 @@ stackTraceToZ(char *buffer, size_t bufferSize, const char *fileName, const char
     if (stackIdx >= 0)
     {
         // If the function passed in was not at the top of the stack then some functions are missing
-        if (stackIdx == stackSize - 1)
+        if (stackIdx == stackTraceLocal.stackSize - 1)
             result += stackTraceFmt(buffer, bufferSize, result, "\n    ... function(s) omitted ...");
 
         // Output the rest of the stack
         for (; stackIdx >= 0; stackIdx--)
         {
-            StackTraceData *data = &stackTrace[stackIdx];
+            StackTraceData *data = &stackTraceLocal.stack[stackIdx];
 
             result += stackTraceFmt(
                 buffer, bufferSize, result, "\n%.*s:%s", (int)(strlen(data->fileName) - 2), data->fileName, data->functionName);
@@ -358,14 +347,10 @@ stackTraceToZ(char *buffer, size_t bufferSize, const char *fileName, const char
     return result;
 }
 
-/***********************************************************************************************************************************
-Clean the stack at and below the try level
-
-Called by the error to cleanup the stack when an exception occurs.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 stackTraceClean(unsigned int tryDepth)
 {
-    while (stackSize > 0 && stackTrace[stackSize - 1].tryDepth >= tryDepth)
-        stackSize--;
+    while (stackTraceLocal.stackSize > 0 && stackTraceLocal.stack[stackTraceLocal.stackSize - 1].tryDepth >= tryDepth)
+        stackTraceLocal.stackSize--;
 }
