@@ -35,15 +35,15 @@ cfgLoadLogSetting(void)
     unsigned int logProcessMax = 1;
 
     if (cfgOptionValid(cfgOptLogLevelConsole))
-        logLevelConsole = logLevelEnum(strPtr(cfgOptionStr(cfgOptLogLevelConsole)));
+        logLevelConsole = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelConsole)));
 
     if (cfgOptionValid(cfgOptLogLevelStderr))
     {
-        logLevelStdErr = logLevelEnum(strPtr(cfgOptionStr(cfgOptLogLevelStderr)));
+        logLevelStdErr = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelStderr)));
     }
 
     if (cfgOptionValid(cfgOptLogLevelFile))
-        logLevelFile = logLevelEnum(strPtr(cfgOptionStr(cfgOptLogLevelFile)));
+        logLevelFile = logLevelEnum(strZ(cfgOptionStr(cfgOptLogLevelFile)));
 
     if (cfgOptionValid(cfgOptLogTimestamp))
         logTimestamp = cfgOptionBool(cfgOptLogTimestamp);
@@ -104,8 +104,8 @@ cfgLoadUpdateOption(void)
                 OptionInvalidValueError,
                 "'%s' is not valid for '" CFGOPT_PROTOCOL_TIMEOUT "' option\nHINT '" CFGOPT_PROTOCOL_TIMEOUT "' option (%s)"
                     " should be greater than '" CFGOPT_DB_TIMEOUT "' option (%s).",
-                strPtr(varStrForce(cfgOption(cfgOptProtocolTimeout))),  strPtr(varStrForce(cfgOption(cfgOptProtocolTimeout))),
-                strPtr(varStrForce(cfgOption(cfgOptDbTimeout))));
+                strZ(varStrForce(cfgOption(cfgOptProtocolTimeout))),  strZ(varStrForce(cfgOption(cfgOptProtocolTimeout))),
+                strZ(varStrForce(cfgOption(cfgOptDbTimeout))));
         }
     }
 
@@ -146,7 +146,7 @@ cfgLoadUpdateOption(void)
                     "option '%s' is not set for '%s=%s', the repository may run out of space"
                     "\nHINT: to retain full backups indefinitely (without warning), set option '%s' to the maximum.",
                     cfgOptionName(cfgOptRepoRetentionFull + optionIdx), cfgOptionName(cfgOptRepoRetentionFullType + optionIdx),
-                    strPtr(cfgOptionStr(cfgOptRepoRetentionFullType + optionIdx)),
+                    strZ(cfgOptionStr(cfgOptRepoRetentionFullType + optionIdx)),
                     cfgOptionName(cfgOptRepoRetentionFull + optionIdx));
             }
         }
@@ -162,7 +162,7 @@ cfgLoadUpdateOption(void)
 
             const String *msgArchiveOff = strNewFmt(
                 "WAL segments will not be expired: option '" CFGOPT_REPO1_RETENTION_ARCHIVE_TYPE "=%s' but",
-                strPtr(archiveRetentionType));
+                strZ(archiveRetentionType));
 
             // If the archive retention is not explicitly set then determine what it should be defaulted to
             if (!cfgOptionTest(cfgOptRepoRetentionArchive + optionIdx))
@@ -189,7 +189,8 @@ cfgLoadUpdateOption(void)
                     }
                     else
                     {
-                        LOG_WARN_FMT("%s neither option '%s' nor option '%s' is set", strPtr(msgArchiveOff),
+                        LOG_WARN_FMT(
+                            "%s neither option '%s' nor option '%s' is set", strZ(msgArchiveOff),
                             cfgOptionName(cfgOptRepoRetentionArchive + optionIdx),
                             cfgOptionName(cfgOptRepoRetentionDiff + optionIdx));
                     }
@@ -198,7 +199,8 @@ cfgLoadUpdateOption(void)
                 {
                     CHECK(strEqZ(archiveRetentionType, CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_INCR));
 
-                    LOG_WARN_FMT("%s option '%s' is not set", strPtr(msgArchiveOff),
+                    LOG_WARN_FMT(
+                        "%s option '%s' is not set", strZ(msgArchiveOff),
                         cfgOptionName(cfgOptRepoRetentionArchive + optionIdx));
                 }
             }
@@ -231,7 +233,7 @@ cfgLoadUpdateOption(void)
                 "\nHINT: RFC-2818 forbids dots in wildcard matches."
                 "\nHINT: TLS/SSL verification cannot proceed with this bucket name."
                 "\nHINT: remove dots from the bucket name.",
-            strPtr(cfgOptionStr(cfgOptRepoS3Bucket)));
+            strZ(cfgOptionStr(cfgOptRepoS3Bucket)));
     }
 
     // Check/update compress-type if compress is valid. There should be no references to the compress option outside this block.
@@ -282,8 +284,8 @@ cfgLoadLogFile(void)
         {
             // Construct log filename prefix
             String *logFile = strNewFmt(
-                "%s/%s-%s", strPtr(cfgOptionStr(cfgOptLogPath)),
-                cfgOptionTest(cfgOptStanza) ? strPtr(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName(cfgCommand()));
+                "%s/%s-%s", strZ(cfgOptionStr(cfgOptLogPath)),
+                cfgOptionTest(cfgOptStanza) ? strZ(cfgOptionStr(cfgOptStanza)): "all", cfgCommandName(cfgCommand()));
 
             // ??? Append async for local/remote archive async commands.  It would be good to find a more generic way to do this in
             // case the async role is added to more commands.
@@ -295,17 +297,17 @@ cfgLoadLogFile(void)
 
             // Add command role if it is not default
             if (cfgCommandRole() != cfgCmdRoleDefault)
-                strCatFmt(logFile, "-%s", strPtr(cfgCommandRoleStr(cfgCommandRole())));
+                strCatFmt(logFile, "-%s", strZ(cfgCommandRoleStr(cfgCommandRole())));
 
             // Add process id if local or remote role
             if (cfgCommandRole() == cfgCmdRoleLocal || cfgCommandRole() == cfgCmdRoleRemote)
                 strCatFmt(logFile, "-%03u", cfgOptionUInt(cfgOptProcess));
 
             // Add extension
-            strCat(logFile, ".log");
+            strCatZ(logFile, ".log");
 
             // Attempt to open log file
-            if (!logFileSet(strPtr(logFile)))
+            if (!logFileSet(strZ(logFile)))
                 cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("off"));
         }
         MEM_CONTEXT_TEMP_END();
@@ -362,7 +364,7 @@ cfgLoad(unsigned int argListSize, const char *argList[])
             cfgLoadLogFile();
 
             // Begin the command
-            cmdBegin(true);
+            cmdBegin();
 
             // Acquire a lock if this command requires a lock
             if (cfgLockRequired() && !cfgCommandHelp())
