@@ -14,9 +14,9 @@ PostgreSQL Info Handler
 #include "common/ini.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/type/json.h"
 #include "common/type/list.h"
+#include "common/type/object.h"
 #include "info/info.h"
 #include "info/infoPg.h"
 #include "postgres/interface.h"
@@ -59,16 +59,18 @@ infoPgNewInternal(InfoPgType type)
     FUNCTION_TEST_END();
 
     InfoPg *this = memNew(sizeof(InfoPg));
-    this->memContext = memContextCurrent();
-    this->type = type;
-    this->history = lstNew(sizeof(InfoPgData));
+
+    *this = (InfoPg)
+    {
+        .memContext = memContextCurrent(),
+        .type = type,
+        .history = lstNewP(sizeof(InfoPgData)),
+    };
 
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Create new object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoPg *
 infoPgNew(InfoPgType type, const String *cipherPassSub)
 {
@@ -89,9 +91,7 @@ infoPgNew(InfoPgType type, const String *cipherPassSub)
     FUNCTION_LOG_RETURN(INFO_PG, this);
 }
 
-/***********************************************************************************************************************************
-Create new object and load contents from a file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 typedef struct InfoPgLoadData
 {
     InfoLoadNewCallback *callbackFunction;                          // Callback function for child object
@@ -101,13 +101,13 @@ typedef struct InfoPgLoadData
 } InfoPgLoadData;
 
 static void
-infoPgLoadCallback(void *data, const String *section, const String *key, const String *value)
+infoPgLoadCallback(void *data, const String *section, const String *key, const Variant *value)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, data);
         FUNCTION_TEST_PARAM(STRING, section);
         FUNCTION_TEST_PARAM(STRING, key);
-        FUNCTION_TEST_PARAM(STRING, value);
+        FUNCTION_TEST_PARAM(VARIANT, value);
     FUNCTION_TEST_END();
 
     ASSERT(data != NULL);
@@ -121,18 +121,17 @@ infoPgLoadCallback(void *data, const String *section, const String *key, const S
     if (strEq(section, INFO_SECTION_DB_STR))
     {
         if (strEq(key, INFO_KEY_DB_ID_STR))
-            loadData->currentId = jsonToUInt(value);
+            loadData->currentId = varUIntForce(value);
     }
     // Process db:history section
     else if (strEq(section, INFO_SECTION_DB_HISTORY_STR))
     {
-        // Load JSON loadData into a KeyValue
-        const KeyValue *pgDataKv = jsonToKv(value);
-
         // Get db values that are common to all info files
+        const KeyValue *pgDataKv = varKv(value);
+
         InfoPgData infoPgData =
         {
-            .id = cvtZToUInt(strPtr(key)),
+            .id = cvtZToUInt(strZ(key)),
             .version = pgVersionFromStr(varStr(kvGet(pgDataKv, INFO_KEY_DB_VERSION_VAR))),
 
             // This is different in archive.info due to a typo that can't be fixed without a format version bump
@@ -204,9 +203,7 @@ infoPgNewLoad(IoRead *read, InfoPgType type, InfoLoadNewCallback *callbackFuncti
     FUNCTION_LOG_RETURN(INFO_PG, this);
 }
 
-/***********************************************************************************************************************************
-Add Postgres data to the history list at position 0 to ensure the latest history is always first in the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 infoPgAdd(InfoPg *this, const InfoPgData *infoPgData)
 {
@@ -224,9 +221,7 @@ infoPgAdd(InfoPg *this, const InfoPgData *infoPgData)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Set the InfoPg object data based on values passed
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoPg *
 infoPgSet(InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uint64_t pgSystemId)
 {
@@ -265,9 +260,7 @@ infoPgSet(InfoPg *this, InfoPgType type, const unsigned int pgVersion, const uin
     FUNCTION_LOG_RETURN(INFO_PG, this);
 }
 
-/***********************************************************************************************************************************
-Save to file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 typedef struct InfoPgSaveData
 {
     InfoSaveCallback *callbackFunction;                             // Callback function for child object
@@ -297,7 +290,7 @@ infoPgSaveCallback(void *data, const String *sectionNext, InfoSave *infoSaveData
 
         InfoPgData pgData = infoPgDataCurrent(saveData->infoPg);
 
-        // These need to be saved because older Perl and C versions expect them
+        // These need to be saved because older pgBackRest versions expect them
         if (saveData->infoPg->type == infoPgBackup)
         {
             infoSaveValue(
@@ -331,7 +324,7 @@ infoPgSaveCallback(void *data, const String *sectionNext, InfoSave *infoSaveData
             {
                 kvPut(pgDataKv, INFO_KEY_DB_SYSTEM_ID_VAR, VARUINT64(pgData.systemId));
 
-                // These need to be saved because older Perl and C versions expect them
+                // These need to be saved because older pgBackRest versions expect them
                 kvPut(pgDataKv, INFO_KEY_DB_CATALOG_VERSION_VAR, VARUINT(pgCatalogVersion(pgData.version)));
                 kvPut(pgDataKv, INFO_KEY_DB_CONTROL_VERSION_VAR, VARUINT(pgControlVersion(pgData.version)));
             }
@@ -379,9 +372,7 @@ infoPgSave(InfoPg *this, IoWrite *write, InfoSaveCallback *callbackFunction, voi
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Construct archive id
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 infoPgArchiveId(const InfoPg *this, unsigned int pgDataIdx)
 {
@@ -394,12 +385,10 @@ infoPgArchiveId(const InfoPg *this, unsigned int pgDataIdx)
 
     InfoPgData pgData = infoPgData(this, pgDataIdx);
 
-    FUNCTION_LOG_RETURN(STRING, strNewFmt("%s-%u", strPtr(pgVersionToStr(pgData.version)), pgData.id));
+    FUNCTION_LOG_RETURN(STRING, strNewFmt("%s-%u", strZ(pgVersionToStr(pgData.version)), pgData.id));
 }
 
-/***********************************************************************************************************************************
-Return the cipher passphrase
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 infoPgCipherPass(const InfoPg *this)
 {
@@ -412,9 +401,7 @@ infoPgCipherPass(const InfoPg *this)
     FUNCTION_TEST_RETURN(infoCipherPass(this->info));
 }
 
-/***********************************************************************************************************************************
-Return a structure of the Postgres data from a specific index
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoPgData
 infoPgData(const InfoPg *this, unsigned int pgDataIdx)
 {
@@ -425,12 +412,10 @@ infoPgData(const InfoPg *this, unsigned int pgDataIdx)
 
     ASSERT(this != NULL);
 
-    FUNCTION_LOG_RETURN(INFO_PG_DATA, *((InfoPgData *)lstGet(this->history, pgDataIdx)));
+    FUNCTION_LOG_RETURN(INFO_PG_DATA, *(InfoPgData *)lstGet(this->history, pgDataIdx));
 }
 
-/***********************************************************************************************************************************
-Return a structure of the current Postgres data
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 InfoPgData
 infoPgDataCurrent(const InfoPg *this)
 {
@@ -443,9 +428,7 @@ infoPgDataCurrent(const InfoPg *this)
     FUNCTION_LOG_RETURN(INFO_PG_DATA, infoPgData(this, infoPgDataCurrentId(this)));
 }
 
-/***********************************************************************************************************************************
-Return the current history index
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 infoPgDataCurrentId(const InfoPg *this)
 {
@@ -458,9 +441,7 @@ infoPgDataCurrentId(const InfoPg *this)
     FUNCTION_LOG_RETURN(UINT, this->historyCurrent);
 }
 
-/***********************************************************************************************************************************
-Get base info
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Info *
 infoPgInfo(const InfoPg *this)
 {
@@ -473,9 +454,7 @@ infoPgInfo(const InfoPg *this)
     FUNCTION_TEST_RETURN(this->info);
 }
 
-/***********************************************************************************************************************************
-Return total Postgres data in the history
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 infoPgDataTotal(const InfoPg *this)
 {
@@ -488,9 +467,7 @@ infoPgDataTotal(const InfoPg *this)
     FUNCTION_LOG_RETURN(UINT, lstSize(this->history));
 }
 
-/***********************************************************************************************************************************
-Return current pgId from the history
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 infoPgCurrentDataId(const InfoPg *this)
 {
@@ -505,9 +482,7 @@ infoPgCurrentDataId(const InfoPg *this)
     FUNCTION_LOG_RETURN(UINT, currentData.id);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 infoPgDataToLog(const InfoPgData *this)
 {
