@@ -31,6 +31,7 @@ Main
 #include "common/debug.h"
 #include "common/error.h"
 #include "common/exit.h"
+#include "common/stat.h"
 #include "config/config.h"
 #include "config/load.h"
 #include "postgres/interface.h"
@@ -52,6 +53,9 @@ main(int argListSize, const char *argList[])
     // Initialize command with the start time
     cmdInit();
 
+    // Initialize statistics collector
+    statInit();
+
     volatile bool result = 0;
     volatile bool error = false;
 
@@ -118,14 +122,17 @@ main(int argListSize, const char *argList[])
                     // Run backup
                     cmdBackup();
 
-                    // Switch to expire command
-                    cmdEnd(0, NULL);
-                    cfgCommandSet(cfgCmdExpire, cfgCmdRoleDefault);
-                    cfgLoadLogFile();
-                    cmdBegin(true);
+                    if (cfgOptionBool(cfgOptExpireAuto))
+                    {
+                        // Switch to expire command
+                        cmdEnd(0, NULL);
+                        cfgCommandSet(cfgCmdExpire, cfgCmdRoleDefault);
+                        cfgLoadLogFile();
+                        cmdBegin();
 
-                    // Run expire
-                    cmdExpire();
+                        // Run expire
+                        cmdExpire();
+                    }
 
                     break;
                 }
