@@ -8,8 +8,8 @@ Postgres Client
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/type/list.h"
+#include "common/type/object.h"
 #include "common/wait.h"
 #include "postgres/client.h"
 
@@ -40,9 +40,7 @@ OBJECT_DEFINE_FREE_RESOURCE_BEGIN(PG_CLIENT, LOG, logLevelTrace)
 }
 OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
-/***********************************************************************************************************************************
-Create object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 PgClient *
 pgClientNew(const String *host, const unsigned int port, const String *database, const String *user, const TimeMSec queryTimeout)
 {
@@ -62,13 +60,16 @@ pgClientNew(const String *host, const unsigned int port, const String *database,
     MEM_CONTEXT_NEW_BEGIN("PgClient")
     {
         this = memNew(sizeof(PgClient));
-        this->memContext = memContextCurrent();
 
-        this->host = strDup(host);
-        this->port = port;
-        this->database = strDup(database);
-        this->user = strDup(user);
-        this->queryTimeout = queryTimeout;
+        *this = (PgClient)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .host = strDup(host),
+            .port = port,
+            .database = strDup(database),
+            .user = strDup(user),
+            .queryTimeout = queryTimeout,
+        };
     }
     MEM_CONTEXT_NEW_END();
 
@@ -102,7 +103,7 @@ pgClientEscape(const String *string)
     // Iterate all characters in the string
     for (unsigned stringIdx = 0; stringIdx < strSize(string); stringIdx++)
     {
-        char stringChar = strPtr(string)[stringIdx];
+        char stringChar = strZ(string)[stringIdx];
 
         // These characters are escaped
         if (stringChar == '\'' || stringChar == '\\')
@@ -116,9 +117,7 @@ pgClientEscape(const String *string)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Open connection to PostgreSQL
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 PgClient *
 pgClientOpen(PgClient *this)
 {
@@ -132,18 +131,18 @@ pgClientOpen(PgClient *this)
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Base connection string
-        String *connInfo = strNewFmt("dbname=%s port=%u", strPtr(pgClientEscape(this->database)), this->port);
+        String *connInfo = strNewFmt("dbname=%s port=%u", strZ(pgClientEscape(this->database)), this->port);
 
         // Add user if specified
         if (this->user != NULL)
-            strCatFmt(connInfo, " user=%s", strPtr(pgClientEscape(this->user)));
+            strCatFmt(connInfo, " user=%s", strZ(pgClientEscape(this->user)));
 
         // Add host if specified
         if (this->host != NULL)
-            strCatFmt(connInfo, " host=%s", strPtr(pgClientEscape(this->host)));
+            strCatFmt(connInfo, " host=%s", strZ(pgClientEscape(this->host)));
 
         // Make the connection
-        this->connection = PQconnectdb(strPtr(connInfo));
+        this->connection = PQconnectdb(strZ(connInfo));
 
         // Set a callback to shutdown the connection
         memContextCallbackSet(this->memContext, pgClientFreeResource, this);
@@ -152,8 +151,8 @@ pgClientOpen(PgClient *this)
         if (PQstatus(this->connection) != CONNECTION_OK)
         {
             THROW_FMT(
-                DbConnectError, "unable to connect to '%s': %s", strPtr(connInfo),
-                strPtr(strTrim(strNew(PQerrorMessage(this->connection)))));
+                DbConnectError, "unable to connect to '%s': %s", strZ(connInfo),
+                strZ(strTrim(strNew(PQerrorMessage(this->connection)))));
         }
 
         // Set notice and warning processor
@@ -164,9 +163,7 @@ pgClientOpen(PgClient *this)
     FUNCTION_LOG_RETURN(PG_CLIENT, this);
 }
 
-/***********************************************************************************************************************************
-Execute a query and return results
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 VariantList *
 pgClientQuery(PgClient *this, const String *query)
 {
@@ -184,11 +181,11 @@ pgClientQuery(PgClient *this, const String *query)
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Send the query without waiting for results so we can timeout if needed
-        if (!PQsendQuery(this->connection, strPtr(query)))
+        if (!PQsendQuery(this->connection, strZ(query)))
         {
             THROW_FMT(
-                DbQueryError, "unable to send query '%s': %s", strPtr(query),
-                strPtr(strTrim(strNew(PQerrorMessage(this->connection)))));
+                DbQueryError, "unable to send query '%s': %s", strZ(query),
+                strZ(strTrim(strNew(PQerrorMessage(this->connection)))));
         }
 
         // Wait for a result
@@ -213,7 +210,7 @@ pgClientQuery(PgClient *this, const String *query)
                 char error[256];
 
                 if (!PQcancel(cancel, error, sizeof(error)))
-                    THROW_FMT(DbQueryError, "unable to cancel query '%s': %s", strPtr(query), strPtr(strTrim(strNew(error))));
+                    THROW_FMT(DbQueryError, "unable to cancel query '%s': %s", strZ(query), strZ(strTrim(strNew(error))));
             }
             FINALLY()
             {
@@ -229,7 +226,7 @@ pgClientQuery(PgClient *this, const String *query)
         {
             // Throw timeout error if cancelled
             if (busy)
-                THROW_FMT(DbQueryError, "query '%s' timed out after %" PRIu64 "ms", strPtr(query), this->queryTimeout);
+                THROW_FMT(DbQueryError, "query '%s' timed out after %" PRIu64 "ms", strZ(query), this->queryTimeout);
 
             // If this was a command that returned no results then we are done
             int resultStatus = PQresultStatus(pgResult);
@@ -240,8 +237,8 @@ pgClientQuery(PgClient *this, const String *query)
                 if (resultStatus != PGRES_TUPLES_OK)
                 {
                     THROW_FMT(
-                        DbQueryError, "unable to execute query '%s': %s", strPtr(query),
-                        strPtr(strTrim(strNew(PQresultErrorMessage(pgResult)))));
+                        DbQueryError, "unable to execute query '%s': %s", strZ(query),
+                        strZ(strTrim(strNew(PQresultErrorMessage(pgResult)))));
                 }
 
                 // Fetch row and column values
@@ -308,7 +305,7 @@ pgClientQuery(PgClient *this, const String *query)
                                     {
                                         THROW_FMT(
                                             FormatError, "unable to parse type %u in column %d for query '%s'",
-                                            columnType[columnIdx], columnIdx, strPtr(query));
+                                            columnType[columnIdx], columnIdx, strZ(query));
                                     }
                                 }
                             }
@@ -330,16 +327,14 @@ pgClientQuery(PgClient *this, const String *query)
         }
         TRY_END();
 
-        varLstMove(result, MEM_CONTEXT_OLD());
+        varLstMove(result, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(VARIANT_LIST, result);
 }
 
-/***********************************************************************************************************************************
-Close connection to PostgreSQL
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 pgClientClose(PgClient *this)
 {
@@ -359,13 +354,11 @@ pgClientClose(PgClient *this)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 pgClientToLog(const PgClient *this)
 {
     return strNewFmt(
-        "{host: %s, port: %u, database: %s, user: %s, queryTimeout %" PRIu64 "}", strPtr(strToLog(this->host)), this->port,
-        strPtr(strToLog(this->database)), strPtr(strToLog(this->user)), this->queryTimeout);
+        "{host: %s, port: %u, database: %s, user: %s, queryTimeout %" PRIu64 "}", strZ(strToLog(this->host)), this->port,
+        strZ(strToLog(this->database)), strZ(strToLog(this->user)), this->queryTimeout);
 }
