@@ -64,7 +64,7 @@ sub codeCountScan
                  $strFile =~ '^test/patch/' ||
                  $strFile =~ '^test/result/' ||
                  $strFile eq 'test/scratch.txt' ||
-                 $strFile eq 'test/src/valgrind.suppress' ||
+                 $strFile =~ '^test/src/valgrind\.suppress\.' ||
                  $strFile eq 'test/src/lcov.conf');
 
         # Classify the source file
@@ -98,6 +98,12 @@ sub codeCountScan
             $strClass .= '/auto';
         }
 
+        # Append vendor if a vendorized file
+        if ($strFile =~ '\.vendor\..$')
+        {
+            $strClass .= '/vendor';
+        }
+
         # Force unrecognized file types
         my $strForceLang = undef;
         my $strType = undef;
