@@ -18,7 +18,7 @@ testRun(void)
     const char *helpVersion = PROJECT_NAME " " PROJECT_VERSION;
 
     // General help text is used in more than one test
-    const char *generalHelp = strPtr(strNewFmt(
+    const char *generalHelp = strZ(strNewFmt(
         "%s - General help\n"
         "\n"
         "Usage:\n"
@@ -94,7 +94,7 @@ testRun(void)
         TEST_RESULT_STR_Z(helpRender(), generalHelp, "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        const char *commandHelp = strPtr(strNewFmt(
+        const char *commandHelp = strZ(strNewFmt(
             "%s%s",
             helpVersion,
             " - 'version' command help\n"
@@ -112,7 +112,7 @@ testRun(void)
 
         // This test is broken up into multiple strings because C99 does not require compilers to support const strings > 4095 bytes
         // -------------------------------------------------------------------------------------------------------------------------
-        commandHelp = strPtr(strNewFmt(
+        commandHelp = strZ(strNewFmt(
             "%s%s%s",
             helpVersion,
             " - 'restore' command help\n"
@@ -124,6 +124,8 @@ testRun(void)
             "\n"
             "Command Options:\n"
             "\n"
+            "  --archive-mode                   preserve or disable archiving on restored\n"
+            "                                   cluster [default=preserve]\n"
             "  --db-include                     restore only specified databases\n"
             "                                   [current=db1, db2]\n"
             "  --force                          force a restore [default=n]\n"
@@ -182,6 +184,16 @@ testRun(void)
             "\n",
             "Repository Options:\n"
             "\n"
+            "  --repo-azure-account             azure repository account\n"
+            "  --repo-azure-ca-file             azure repository TLS CA file\n"
+            "  --repo-azure-ca-path             azure repository TLS CA path\n"
+            "  --repo-azure-container           azure repository container\n"
+            "  --repo-azure-host                azure repository host\n"
+            "  --repo-azure-key                 azure repository key\n"
+            "  --repo-azure-key-type            azure repository key type [default=shared]\n"
+            "  --repo-azure-port                azure repository server port [default=443]\n"
+            "  --repo-azure-verify-tls          azure repository server certificate verify\n"
+            "                                   [default=y]\n"
             "  --repo-cipher-pass               repository cipher passphrase\n"
             "                                   [current=<redacted>]\n"
             "  --repo-cipher-type               cipher used to encrypt the repository\n"
@@ -208,8 +220,10 @@ testRun(void)
             "  --repo-s3-host                   s3 repository host\n"
             "  --repo-s3-key                    s3 repository access key\n"
             "  --repo-s3-key-secret             s3 repository secret access key\n"
+            "  --repo-s3-key-type               s3 repository key type [default=shared]\n"
             "  --repo-s3-port                   s3 repository port [default=443]\n"
             "  --repo-s3-region                 s3 repository region\n"
+            "  --repo-s3-role                   s3 repository role\n"
             "  --repo-s3-token                  s3 repository security token\n"
             "  --repo-s3-uri-style              s3 URI Style [default=host]\n"
             "  --repo-s3-verify-tls             verify S3 server certificate [default=y]\n"
@@ -257,7 +271,7 @@ testRun(void)
         TEST_ERROR(helpRender(), OptionInvalidError, "option 'BOGUS' is not valid for command 'archive-push'");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        const char *optionHelp = strPtr(strNewFmt(
+        const char *optionHelp = strZ(strNewFmt(
             "%s - 'archive-push' command - 'buffer-size' option help\n"
             "\n"
             "Buffer size for file operations.\n"
@@ -289,7 +303,7 @@ testRun(void)
         TEST_RESULT_STR(helpRender(), strNewFmt("%s\ncurrent: 32768\ndefault: 1048576\n", optionHelp), "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        optionHelp = strPtr(strNewFmt(
+        optionHelp = strZ(strNewFmt(
             "%s - 'archive-push' command - 'repo1-s3-host' option help\n"
             "\n"
             "S3 repository host.\n"
@@ -313,7 +327,7 @@ testRun(void)
         TEST_RESULT_STR(helpRender(), strNewFmt("%s\ncurrent: s3-host\n", optionHelp), "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        optionHelp = strPtr(strNewFmt(
+        optionHelp = strZ(strNewFmt(
             "%s - 'archive-push' command - 'repo-cipher-pass' option help\n"
             "\n"
             "Repository cipher passphrase.\n"
@@ -336,7 +350,7 @@ testRun(void)
         TEST_RESULT_STR_Z(helpRender(), optionHelp, "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        optionHelp = strPtr(strNewFmt(
+        optionHelp = strZ(strNewFmt(
             "%s - 'backup' command - 'repo-hardlink' option help\n"
             "\n"
             "Hardlink files between backups in the repository.\n"
@@ -362,7 +376,7 @@ testRun(void)
 
         // Check admonition
         // -------------------------------------------------------------------------------------------------------------------------
-        optionHelp = strPtr(strNewFmt(
+        optionHelp = strZ(strNewFmt(
             "%s - 'backup' command - 'repo-retention-archive' option help\n"
             "\n"
             "Number of backups worth of continuous WAL to retain.\n"
@@ -408,7 +422,7 @@ testRun(void)
         int stdoutSave = dup(STDOUT_FILENO);
         String *stdoutFile = strNewFmt("%s/stdout.help", testPath());
 
-        THROW_ON_SYS_ERROR(freopen(strPtr(stdoutFile), "w", stdout) == NULL, FileWriteError, "unable to reopen stdout");
+        THROW_ON_SYS_ERROR(freopen(strZ(stdoutFile), "w", stdout) == NULL, FileWriteError, "unable to reopen stdout");
 
         // Not in a test wrapper to avoid writing to stdout
         cmdHelp();
